"""Statics"""
__docformat__ = "numpy"

BENCHMARK_CHOICES = {
    "SPY": "SPDR S&P 500 ETF Trust (SPY)",
    "IVV": "iShares Core S&P 500 ETF (IVV)",
    "VTI": "Vanguard Total Stock Market ETF (VTI)",
    "VOO": "Vanguard S&P 500 ETF (VOO)",
    "QQQ": "Invesco QQQ Trust (QQQ)",
    "VTV": "Vanguard Value ETF (VTV)",
    "VEA": "Vanguard FTSE Developed Markets ETF (VEA)",
    "IEFA": "iShares Core MSCI EAFE ETF (IEFA)",
    "AGG": "iShares Core U.S. Aggregate Bond ETF (AGG)",
    "BND": "Vanguard Total Bond Market ETF (BND)",
    "VWO": "Vanguard FTSE Emerging Markets ETF (VWO)",
    "VUG": "Vanguard Growth ETF (VUG)",
    "IEMG": "iShares Core MSCI Emerging Markets ETF (IEMG)",
    "IJR": "iShares Core S&P Small-Cap ETF (IJR)",
    "GLD": "SPDR Gold Shares (GLD)",
    "IWF": "iShares Russell 1000 Growth ETF (IWF)",
    "IJH": "iShares Core S&P Mid-Cap ETF (IJH)",
    "VIG": "Vanguard Dividend Appreciation ETF (VIG)",
    "IWM": "iShares Russell 2000 ETF (IWM)",
    "IWD": "iShares Russell 1000 Value ETF (IWD)",
    "VO": "Vanguard Mid-Cap ETF (VO)",
    "EFA": "iShares MSCI EAFE ETF (EFA)",
    "VXUS": "Vanguard Total International Stock ETF (VXUS)",
    "VGT": "Vanguard Information Technology ETF (VGT)",
    "VYM": "Vanguard High Dividend Yield Index ETF (VYM)",
    "BNDX": "Vanguard Total International Bond ETF (BNDX)",
    "VNQ": "Vanguard Real Estate ETF (VNQ)",
    "VB": "Vanguard Small Cap ETF (VB)",
    "XLK": "Technology Select Sector SPDR Fund (XLK)",
    "ITOT": "iShares Core S&P Total U.S. Stock Market ETF (ITOT)",
    "VCIT": "Vanguard Intermediate-Term Corporate Bond ETF (VCIT)",
    "VCSH": "Vanguard Short-Term Corporate Bond ETF (VCSH)",
    "XLE": "Energy Select Sector SPDR Fund (XLE)",
    "XLV": "Health Care Select Sector SPDR Fund (XLV)",
    "BSV": "Vanguard Short-Term Bond ETF (BSV)",
    "XLF": "Financial Select Sector SPDR Fund (XLF)",
    "SCHD": "Schwab US Dividend Equity ETF (SCHD)",
    "RSP": "Invesco S&P 500® Equal Weight ETF (RSP)",
    "LQD": "iShares iBoxx $ Investment Grade Corporate Bond ETF (LQD)",
    "IVW": "iShares S&P 500 Growth ETF (IVW)",
    "VEU": "Vanguard FTSE All-World ex-US Index Fund (VEU)",
    "TIP": "iShares TIPS Bond ETF (TIP)",
    "IAU": "iShares Gold Trust (IAU)",
    "SCHX": "Schwab U.S. Large-Cap ETF (SCHX)",
    "IXUS": "iShares Core MSCI Total International Stock ETF (IXUS)",
    "IWR": "iShares Russell Midcap ETF (IWR)",
    "IWB": "iShares Russell 1000 ETF (IWB)",
    "DIA": "SPDR Dow Jones Industrial Average ETF Trust (DIA)",
    "EEM": "iShares MSCI Emerging Markets ETF (EEM)",
    "USMV": "iShares MSCI USA Min Vol Factor ETF (USMV)",
    "SCHF": "Schwab International Equity ETF (SCHF)",
    "IVE": "iShares S&P 500 Value ETF (IVE)",
    "MUB": "iShares National Muni Bond ETF (MUB)",
    "VV": "Vanguard Large Cap ETF (VV)",
    "VBR": "Vanguard Small Cap Value ETF (VBR)",
    "ESGU": "iShares ESG Aware MSCI USA ETF (ESGU)",
    "VT": "Vanguard Total World Stock ETF (VT)",
    "DGRO": "iShares Core Dividend Growth ETF (DGRO)",
    "SHY": "iShares 1-3 Year Treasury Bond ETF (SHY)",
    "DVY": "iShares Select Dividend ETF (DVY)",
    "QUAL": "iShares MSCI USA Quality Factor ETF (QUAL)",
    "SCHB": "Schwab U.S. Broad Market ETF (SCHB)",
    "MBB": "iShares MBS ETF (MBB)",
    "SDY": "SPDR S&P Dividend ETF (SDY)",
    "IGSB": "iShares 1-5 Year Investment Grade Corporate Bond ETF (IGSB)",
    "VTIP": "Vanguard Short-Term Inflation-Protected Securities ETF (VTIP)",
    "JPST": "JPMorgan Ultra-Short Income ETF (JPST)",
    "TLT": "iShares 20+ Year Treasury Bond ETF (TLT)",
    "ACWI": "iShares MSCI ACWI ETF (ACWI)",
    "MDY": "SPDR S&P Midcap 400 ETF Trust (MDY)",
    "IUSB": "iShares Core Total USD Bond Market ETF (IUSB)",
    "SHV": "iShares Short Treasury Bond ETF (SHV)",
    "VGK": "Vanguard FTSE Europe ETF (VGK)",
    "XLY": "Consumer Discretionary Select Sector SPDR Fund (XLY)",
    "BIL": "SPDR Bloomberg 1-3 Month T-Bill ETF (BIL)",
    "GOVT": "iShares U.S. Treasury Bond ETF (GOVT)",
    "VHT": "Vanguard Health Care ETF (VHT)",
    "VOE": "Vanguard Mid-Cap Value ETF (VOE)",
    "XLP": "Consumer Staples Select Sector SPDR Fund (XLP)",
    "SCHP": "Schwab U.S. TIPS ETF (SCHP)",
    "IEF": "iShares 7-10 Year Treasury Bond ETF (IEF)",
    "PFF": "iShares Preferred & Income Securities ETF (PFF)",
    "XLU": "Utilities Select Sector SPDR Fund (XLU)",
    "VTEB": "Vanguard Tax-Exempt Bond ETF (VTEB)",
    "EFV": "iShares MSCI EAFE Value ETF (EFV)",
    "SCHG": "Schwab U.S. Large-Cap Growth ETF (SCHG)",
    "EMB": "iShares J.P. Morgan USD Emerging Markets Bond ETF (EMB)",
    "DFAC": "Dimensional U.S. Core Equity 2 ETF (DFAC)",
    "SCHA": "Schwab U.S. Small-Cap ETF (SCHA)",
    "GDX": "VanEck Gold Miners ETF (GDX)",
    "VMBS": "Vanguard Mortgage-Backed Securities ETF (VMBS)",
    "TQQQ": "ProShares UltraPro QQQ (TQQQ)",
    "VGSH": "Vanguard Short-Term Treasury ETF (VGSH)",
    "HYG": "iShares iBoxx $ High Yield Corporate Bond ETF (HYG)",
    "XLI": "Industrial Select Sector SPDR Fund (XLI)",
    "IWS": "iShares Russell Mid-Cap Value ETF (IWS)",
    "VXF": "Vanguard Extended Market ETF (VXF)",
    "SPLG": "SPDR Portfolio S&P 500 ETF (SPLG)",
    "SPYV": "SPDR Portfolio S&P 500 Value ETF (SPYV)",
    "IWN": "iShares Russell 2000 Value ETF (IWN)",
}

PERIODS = ["mtd", "qtd", "ytd", "3m", "6m", "1y", "3y", "5y", "10y", "all"]

REGIONS = {
    "Afghanistan": "Middle East",
    "Anguilla": "North America",
    "Argentina": "Latin America",
    "Australia": "Asia",
    "Austria": "Europe",
    "Azerbaijan": "Europe",
    "Bahamas": "North America",
    "Bangladesh": "Asia",
    "Barbados": "North America",
    "Belgium": "Europe",
    "Belize": "North America",
    "Bermuda": "North America",
    "Botswana": "Africa",
    "Brazil": "Latin America",
    "British Virgin Islands": "North America",
    "Cambodia": "Asia",
    "Canada": "North America",
    "Cayman Islands": "North America",
    "Chile": "Latin America",
    "China": "Asia",
    "Colombia": "Latin America",
    "Costa Rica": "North America",
    "Cyprus": "Europe",
    "Czech Republic": "Europe",
    "Denmark": "Europe",
    "Dominican Republic": "North America",
    "Egypt": "Middle East",
    "Estonia": "Europe",
    "Falkland Islands": "Latin America",
    "Finland": "Europe",
    "France": "Europe",
    "French Guiana": "Europe",
    "Gabon": "Africa",
    "Georgia": "Europe",
    "Germany": "Europe",
    "Ghana": "Africa",
    "Gibraltar": "Europe",
    "Greece": "Europe",
    "Greenland": "North America",
    "Guernsey": "Europe",
    "Hong Kong": "Asia",
    "Hungary": "Europe",
    "Iceland": "Europe",
    "India": "Asia",
    "Indonesia": "Asia",
    "Ireland": "Europe",
    "Isle of Man": "Europe",
    "Israel": "Middle East",
    "Italy": "Europe",
    "Ivory Coast": "Africa",
    "Japan": "Asia",
    "Jersey": "Europe",
    "Jordan": "Middle East",
    "Kazakhstan": "Asia",
    "Kyrgyzstan": "Asia",
    "Latvia": "Europe",
    "Liechtenstein": "Europe",
    "Lithuania": "Europe",
    "Luxembourg": "Europe",
    "Macau": "Asia",
    "Macedonia": "Europe",
    "Malaysia": "Asia",
    "Malta": "Europe",
    "Mauritius": "Africa",
    "Mexico": "Latin America",
    "Monaco": "Europe",
    "Mongolia": "Asia",
    "Montenegro": "Europe",
    "Morocco": "Africa",
    "Mozambique": "Africa",
    "Myanmar": "Asia",
    "Namibia": "Africa",
    "Netherlands": "Europe",
    "Netherlands Antilles": "Europe",
    "New Zealand": "Asia",
    "Nigeria": "Africa",
    "Norway": "Europe",
    "Panama": "North America",
    "Papua New Guinea": "Asia",
    "Peru": "Latin America",
    "Philippines": "Asia",
    "Poland": "Europe",
    "Portugal": "Europe",
    "Qatar": "Middle East",
    "Reunion": "Africa",
    "Romania": "Europe",
    "Russia": "Asia",
    "Saudi Arabia": "Middle East",
    "Senegal": "Africa",
    "Singapore": "Asia",
    "Slovakia": "Europe",
    "Slovenia": "Europe",
    "South Africa": "Africa",
    "South Korea": "Asia",
    "Spain": "Europe",
    "Suriname": "Latin America",
    "Sweden": "Europe",
    "Switzerland": "Europe",
    "Taiwan": "Asia",
    "Tanzania": "Africa",
    "Thailand": "Asia",
    "Turkey": "Middle East",
    "Ukraine": "Europe",
    "United Arab Emirates": "Middle East",
    "United Kingdom": "Europe",
    "United States": "North America",
    "Uruguay": "Latin America",
    "Vietnam": "Asia",
    "Zambia": "Africa",
}
